pub struct Configuration { /* private fields */ }Expand description
A struct that contains a file buffer which represents a configuration file. It can then be used to read options from.
Implementations